# weighbridge-agent

An agent for weighbridges to export serial ports communicating with TCP protocol.

## License

Copyright (C) 2023 HE Yaowen <he.yaowen@hotmail.com>

The BSD 3-Clause License, see [LICENSE](./LICENSE).
